@@ -165,13 +165,13 @@ class CfnProfilingGroup(
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''The full Amazon Resource Name (ARN) for that profiling group.
@@ -180,12 +180,12 @@ class CfnProfilingGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> aws_cdk.core.TagManager:
         '''A list of tags to add to the created profiling group.
@@ -194,7 +194,7 @@ class CfnProfilingGroup(
         '''
         return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="agentPermissions")
     def agent_permissions(self) -> typing.Any:
         '''The agent permissions attached to this profiling group.
@@ -216,7 +216,7 @@ class CfnProfilingGroup(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "agentPermissions", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''The name of the profiling group.
@@ -232,7 +232,7 @@ class CfnProfilingGroup(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profilingGroupName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
     def anomaly_detection_notification_configuration(
         self,
@@ -253,7 +253,7 @@ class CfnProfilingGroup(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="computePlatform")
     def compute_platform(self) -> typing.Optional[builtins.str]:
         '''The compute platform of the profiling group.
@@ -515,7 +515,7 @@ class ComputePlatform(enum.Enum):
 class IProfilingGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
     '''IResource represents a Profiling Group.'''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''A name for the profiling group.
@@ -555,13 +555,13 @@ class IProfilingGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IProfilingGroupProxy(
-    jsii.proxy_for(aws_cdk.core.IResource) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
 ):
     '''IResource represents a Profiling Group.'''
 
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-codeguruprofiler.IProfilingGroup"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''A name for the profiling group.
@@ -655,7 +655,7 @@ class ProfilingGroup(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromProfilingGroupArn") # type: ignore[misc]
+    @jsii.member(jsii_name="fromProfilingGroupArn")
     @builtins.classmethod
     def from_profiling_group_arn(
         cls,
@@ -676,7 +676,7 @@ class ProfilingGroup(
             check_type(argname="argument profiling_group_arn", value=profiling_group_arn, expected_type=type_hints["profiling_group_arn"])
         return typing.cast(IProfilingGroup, jsii.sinvoke(cls, "fromProfilingGroupArn", [scope, id, profiling_group_arn]))
 
-    @jsii.member(jsii_name="fromProfilingGroupName") # type: ignore[misc]
+    @jsii.member(jsii_name="fromProfilingGroupName")
     @builtins.classmethod
     def from_profiling_group_name(
         cls,
@@ -732,7 +732,7 @@ class ProfilingGroup(
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupArn")
     def profiling_group_arn(self) -> builtins.str:
         '''The ARN of the Profiling Group.
@@ -741,7 +741,7 @@ class ProfilingGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "profilingGroupArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
         '''The name of the Profiling Group.
